@@ -357,8 +357,8 @@ stored_image_store (ByzanzRecorder *rec, GdkImage *image, GdkRegion *region, con
   store->offset = offset;
   gdk_region_get_rectangles (store->region, &rects, &nrects);
   for (i = 0; i < nrects; i++) {
-    gpointer mem;
-    mem = image->mem + rects[i].x * image->bpp + image->bpl * rects[i].y
+    guchar *mem;
+    mem = (guchar *) image->mem + rects[i].x * image->bpp + image->bpl * rects[i].y
 	+ (image->bpp == 4 && image->byte_order == GDK_MSB_FIRST ? 1 : 0);
     for (line = 0; line < rects[i].height; line++) {
       int amount = rects[i].width * image->bpp;
@@ -454,7 +454,7 @@ byzanz_recorder_quantize (ByzanzRecorder *rec, GdkImage *image)
   GifencPalette *palette;
 
   palette = gifenc_quantize_image (
-      image->mem + (image->bpp == 4 && image->byte_order == GDK_MSB_FIRST ? 1 : 0),
+      (guchar *) image->mem + (image->bpp == 4 && image->byte_order == GDK_MSB_FIRST ? 1 : 0),
       rec->area.width, rec->area.height, image->bpp, image->bpl, TRUE,
       (image->byte_order == GDK_MSB_FIRST) ? G_BIG_ENDIAN : G_LITTLE_ENDIAN, 
       255);
@@ -470,7 +470,7 @@ byzanz_recorder_encode_get_data (ByzanzRecorder *rec, gpointer data, GdkRectangl
 {
   GdkImage *image = data;
 
-  *data_out = image->mem + rect->y * image->bpl + rect->x * image->bpp + 
+  *data_out = (guchar *) image->mem + rect->y * image->bpl + rect->x * image->bpp + 
 	    (image->bpp == 4 && image->byte_order == GDK_MSB_FIRST ? 1 : 0);
   *bpp_out = image->bpp;
   *bpl_out = image->bpl;
@@ -577,7 +577,7 @@ loop:
     rec->file_cache_data_size = 0;
   }
   g_queue_free (rec->file_cache);
-  g_atomic_int_dec_and_test (&rec->encoder_running);
+  g_atomic_int_add (&rec->encoder_running, -1);
 
   return rec;
 #undef USING_FILE_CACHE
@@ -616,7 +616,7 @@ render_cursor_to_image (GdkImage *image, XFixesCursorImage *cursor, gint x, gint
       + 1
 #endif
     ;
-  image_data = image->mem + rect.x * image->bpp + image->bpl * rect.y
+  image_data = (guchar *) image->mem + rect.x * image->bpp + image->bpl * rect.y
 	+ (image->bpp == 4 && image->byte_order == GDK_MSB_FIRST ? 1 : 0);
   for (i = 0; i < rect.height; i++) {
     cursor_row = cursor_data;
@@ -824,6 +824,8 @@ byzanz_recorder_new (const gchar *filename, GdkWindow *window, GdkRectangle *are
   g_return_val_if_fail (area->y >= 0, NULL);
   g_return_val_if_fail (area->width > 0, NULL);
   g_return_val_if_fail (area->height > 0, NULL);
+  g_return_val_if_fail (gdk_drawable_get_depth (window) == 24 || \
+      gdk_drawable_get_depth (window) == 32, NULL);
   
   fd = g_open (filename, O_WRONLY | O_CREAT | O_TRUNC, 0666);
   if (fd < 0)
@@ -844,6 +846,8 @@ byzanz_recorder_new_fd (gint fd, GdkWindow *window, GdkRectangle *area,
   g_return_val_if_fail (area->y >= 0, NULL);
   g_return_val_if_fail (area->width > 0, NULL);
   g_return_val_if_fail (area->height > 0, NULL);
+  g_return_val_if_fail (gdk_drawable_get_depth (window) == 24 || \
+      gdk_drawable_get_depth (window) == 32, NULL);
   
   dpy = gdk_x11_display_get_xdisplay (gdk_display_get_default ());
   if (dmg_event_base == 0) {
